@@ -6,10 +6,10 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/charmbracelet/keygen"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
@@ -186,7 +186,7 @@ func TestFullPipe(t *testing.T) {
 					Branch: "main",
 					Git: config.GitRepoRef{
 						URL:        testlib.GitMakeBareRepository(t),
-						PrivateKey: testlib.MakeNewSSHKey(t, keygen.Ed25519, ""),
+						PrivateKey: testlib.MakeNewSSHKey(t, ""),
 					},
 				}
 			},
@@ -1228,7 +1228,14 @@ func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
 		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
-
+	t.Run("skip flag", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
+			Brews: []config.Homebrew{
+				{},
+			},
+		}, testctx.Skip(skips.Homebrew))
+		require.True(t, Pipe{}.Skip(ctx))
+	})
 	t.Run("dont skip", func(t *testing.T) {
 		ctx := testctx.NewWithCfg(config.Project{
 			Brews: []config.Homebrew{
