@@ -2,8 +2,10 @@ package release
 
 import (
 	"bytes"
+	"os"
 	"text/template"
 
+	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
@@ -15,7 +17,21 @@ const bodyTemplateText = `{{ with .Header }}{{ . }}{{ "\n" }}{{ end }}
 
 func describeBody(ctx *context.Context) (bytes.Buffer, error) {
 	var out bytes.Buffer
-	t := tmpl.New(ctx)
+	var checksum string
+	if l := ctx.Artifacts.Filter(artifact.ByType(artifact.Checksum)).List(); len(l) > 0 {
+		if err := l[0].Refresh(); err != nil {
+			return out, err
+		}
+		bts, err := os.ReadFile(l[0].Path)
+		if err != nil {
+			return out, err
+		}
+		checksum = string(bts)
+	}
+
+	t := tmpl.New(ctx).WithExtraFields(tmpl.Fields{
+		"Checksums": checksum,
+	})
 
 	header, err := t.Apply(ctx.Config.Release.Header)
 	if err != nil {
