@@ -15,20 +15,21 @@ import (
 	"github.com/goreleaser/goreleaser/internal/ids"
 	"github.com/goreleaser/goreleaser/internal/logext"
 	"github.com/goreleaser/goreleaser/internal/semerrgroup"
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
 
 // Environment variables to pass through to exec
-var passthroughEnvVars = []string{"HOME", "USER", "USERPROFILE", "TMPDIR", "TMP", "TEMP", "PATH"}
+var passthroughEnvVars = []string{"HOME", "USER", "USERPROFILE", "TMPDIR", "TMP", "TEMP", "PATH", "LOCALAPPDATA"}
 
 // Pipe that catalogs common artifacts as an SBOM.
 type Pipe struct{}
 
 func (Pipe) String() string { return "cataloging artifacts" }
 func (Pipe) Skip(ctx *context.Context) bool {
-	return ctx.SkipSBOMCataloging || len(ctx.Config.SBOMs) == 0
+	return skips.Any(ctx, skips.SBOM) || len(ctx.Config.SBOMs) == 0
 }
 
 func (Pipe) Dependencies(ctx *context.Context) []string {
@@ -148,6 +149,8 @@ func catalog(ctx *context.Context, cfg config.SBOM, artifacts []*artifact.Artifa
 }
 
 func subprocessDistPath(distDir string, pathRelativeToCwd string) (string, error) {
+	distDir = filepath.Clean(distDir)
+	pathRelativeToCwd = filepath.Clean(pathRelativeToCwd)
 	cwd, err := os.Getwd()
 	if err != nil {
 		return "", err
@@ -195,6 +198,11 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 	cmd.Env = append(cmd.Env, envs...)
 	cmd.Dir = ctx.Config.Dist
 
+	log.WithField("env", cmd.Env).
+		WithField("dir", cmd.Dir).
+		WithField("cmd", cmd.Args).
+		Debug("running")
+
 	var b bytes.Buffer
 	w := gio.Safe(&b)
 	cmd.Stderr = io.MultiWriter(logext.NewWriter(), w)
